[Sumover-dev] [svn commit] r4277 - vic/branches/cc/cc

sumover-dev at cs.ucl.ac.uk sumover-dev at cs.ucl.ac.uk
Mon Aug 18 01:55:15 BST 2008


Author: soohyunc
Date: Mon Aug 18 01:55:12 2008
New Revision: 4277

Modified:
   vic/branches/cc/cc/tfwc_sndr.cpp
   vic/branches/cc/cc/tfwc_sndr.h

Log:
o  bug fix: previous ts_ and ts_echo_ was (u_int32_t) type. 
            now it has changed to (double) type.


Modified: vic/branches/cc/cc/tfwc_sndr.cpp
==============================================================================
--- vic/branches/cc/cc/tfwc_sndr.cpp	(original)
+++ vic/branches/cc/cc/tfwc_sndr.cpp	Mon Aug 18 01:55:12 2008
@@ -50,8 +50,8 @@
 	cwnd_(1),
 	aoa_(0),
 	t_now_(0),
-	ts_(0),
-	ts_echo_(0),
+	t_ts_(0),
+	t_ts_echo_(0),
 	now_(0),
 	ndtp_(0),
 	nakp_(0),
@@ -81,6 +81,7 @@
 	beta_ = 0.25;
 	g_ = 0.01;
 	k_ = 4;
+	ts_ = 0.0;
 
 	is_tfwc_on_ = false;
 	is_first_loss_seen_ = false;

Modified: vic/branches/cc/cc/tfwc_sndr.h
==============================================================================
--- vic/branches/cc/cc/tfwc_sndr.h	(original)
+++ vic/branches/cc/cc/tfwc_sndr.h	Mon Aug 18 01:55:12 2008
@@ -159,8 +159,9 @@
 	u_int32_t pvec_;	// sent packet list
 	u_int16_t aoa_;		// ack of ack
 	u_int32_t t_now_;	// the time when the data packet sent
-	u_int32_t ts_;		// time stamp
-	u_int32_t ts_echo_;	// echo time stamp from the receiver
+	u_int32_t t_ts_;		// time stamp (u_int32_t type)
+	u_int32_t t_ts_echo_;	// echo time stamp from the receiver
+	double ts_;			// time stamp (double type)
 	double now_;		// real-time now
 	double tao_;		// sampled RTT
 private:



More information about the Sumover-dev mailing list